| appstream | R Documentation |
Amazon WorkSpaces Applications
This is the Amazon WorkSpaces Applications API Reference. This documentation provides descriptions and syntax for each of the actions and data types in WorkSpaces Applications. WorkSpaces Applications is a fully managed, secure application streaming service that lets you stream desktop applications to users without rewriting applications. WorkSpaces Applications manages the AWS resources that are required to host and run your applications, scales automatically, and provides access to your users on demand.
You can call the WorkSpaces Applications API operations by using an interface VPC endpoint (interface endpoint). For more information, see Access WorkSpaces Applications API Operations and CLI Commands Through an Interface VPC Endpoint in the Amazon WorkSpaces Applications Administration Guide.
To learn more about WorkSpaces Applications, see the following resources:
appstream(
config = list(),
credentials = list(),
endpoint = NULL,
region = NULL
)
config |
Optional configuration of credentials, endpoint, and/or region.
|
credentials |
Optional credentials shorthand for the config parameter
|
endpoint |
Optional shorthand for complete URL to use for the constructed client. |
region |
Optional shorthand for AWS Region used in instantiating the client. |
A client for the service. You can call the service's operations using
syntax like svc$operation(...), where svc is the name you've assigned
to the client. The available operations are listed in the
Operations section.
svc <- appstream(
config = list(
credentials = list(
creds = list(
access_key_id = "string",
secret_access_key = "string",
session_token = "string"
),
profile = "string",
anonymous = "logical"
),
endpoint = "string",
region = "string",
close_connection = "logical",
timeout = "numeric",
s3_force_path_style = "logical",
sts_regional_endpoint = "string"
),
credentials = list(
creds = list(
access_key_id = "string",
secret_access_key = "string",
session_token = "string"
),
profile = "string",
anonymous = "logical"
),
endpoint = "string",
region = "string"
)
| associate_app_block_builder_app_block | Associates the specified app block builder with the specified app block |
| associate_application_fleet | Associates the specified application with the specified fleet |
| associate_application_to_entitlement | Associates an application to entitle |
| associate_fleet | Associates the specified fleet with the specified stack |
| associate_software_to_image_builder | Associates license included application(s) with an existing image builder instance |
| batch_associate_user_stack | Associates the specified users with the specified stacks |
| batch_disassociate_user_stack | Disassociates the specified users from the specified stacks |
| copy_image | Copies the image within the same region or to a new region within the same AWS account |
| create_app_block | Creates an app block |
| create_app_block_builder | Creates an app block builder |
| create_app_block_builder_streaming_url | Creates a URL to start a create app block builder streaming session |
| create_application | Creates an application |
| create_directory_config | Creates a Directory Config object in WorkSpaces Applications |
| create_entitlement | Creates a new entitlement |
| create_export_image_task | Creates a task to export a WorkSpaces Applications image to an EC2 AMI |
| create_fleet | Creates a fleet |
| create_image_builder | Creates an image builder |
| create_image_builder_streaming_url | Creates a URL to start an image builder streaming session |
| create_imported_image | Creates a custom WorkSpaces Applications image by importing an EC2 AMI |
| create_stack | Creates a stack to start streaming applications to users |
| create_streaming_url | Creates a temporary URL to start an WorkSpaces Applications streaming session for the specified user |
| create_theme_for_stack | Creates custom branding that customizes the appearance of the streaming application catalog page |
| create_updated_image | Creates a new image with the latest Windows operating system updates, driver updates, and WorkSpaces Applications agent software |
| create_usage_report_subscription | Creates a usage report subscription |
| create_user | Creates a new user in the user pool |
| delete_app_block | Deletes an app block |
| delete_app_block_builder | Deletes an app block builder |
| delete_application | Deletes an application |
| delete_directory_config | Deletes the specified Directory Config object from WorkSpaces Applications |
| delete_entitlement | Deletes the specified entitlement |
| delete_fleet | Deletes the specified fleet |
| delete_image | Deletes the specified image |
| delete_image_builder | Deletes the specified image builder and releases the capacity |
| delete_image_permissions | Deletes permissions for the specified private image |
| delete_stack | Deletes the specified stack |
| delete_theme_for_stack | Deletes custom branding that customizes the appearance of the streaming application catalog page |
| delete_usage_report_subscription | Disables usage report generation |
| delete_user | Deletes a user from the user pool |
| describe_app_block_builder_app_block_associations | Retrieves a list that describes one or more app block builder associations |
| describe_app_block_builders | Retrieves a list that describes one or more app block builders |
| describe_app_blocks | Retrieves a list that describes one or more app blocks |
| describe_application_fleet_associations | Retrieves a list that describes one or more application fleet associations |
| describe_applications | Retrieves a list that describes one or more applications |
| describe_app_license_usage | Retrieves license included application usage information |
| describe_directory_configs | Retrieves a list that describes one or more specified Directory Config objects for WorkSpaces Applications, if the names for these objects are provided |
| describe_entitlements | Retrieves a list that describes one of more entitlements |
| describe_fleets | Retrieves a list that describes one or more specified fleets, if the fleet names are provided |
| describe_image_builders | Retrieves a list that describes one or more specified image builders, if the image builder names are provided |
| describe_image_permissions | Retrieves a list that describes the permissions for shared AWS account IDs on a private image that you own |
| describe_images | Retrieves a list that describes one or more specified images, if the image names or image ARNs are provided |
| describe_sessions | Retrieves a list that describes the streaming sessions for a specified stack and fleet |
| describe_software_associations | Retrieves license included application associations for a specified resource |
| describe_stacks | Retrieves a list that describes one or more specified stacks, if the stack names are provided |
| describe_theme_for_stack | Retrieves a list that describes the theme for a specified stack |
| describe_usage_report_subscriptions | Retrieves a list that describes one or more usage report subscriptions |
| describe_users | Retrieves a list that describes one or more specified users in the user pool |
| describe_user_stack_associations | Retrieves a list that describes the UserStackAssociation objects |
| disable_user | Disables the specified user in the user pool |
| disassociate_app_block_builder_app_block | Disassociates a specified app block builder from a specified app block |
| disassociate_application_fleet | Disassociates the specified application from the fleet |
| disassociate_application_from_entitlement | Deletes the specified application from the specified entitlement |
| disassociate_fleet | Disassociates the specified fleet from the specified stack |
| disassociate_software_from_image_builder | Removes license included application(s) association(s) from an image builder instance |
| drain_session_instance | Drains the instance hosting the specified streaming session |
| enable_user | Enables a user in the user pool |
| expire_session | Immediately stops the specified streaming session |
| get_export_image_task | Retrieves information about an export image task, including its current state, progress, and any error details |
| list_associated_fleets | Retrieves the name of the fleet that is associated with the specified stack |
| list_associated_stacks | Retrieves the name of the stack with which the specified fleet is associated |
| list_entitled_applications | Retrieves a list of entitled applications |
| list_export_image_tasks | Lists export image tasks, with optional filtering and pagination |
| list_tags_for_resource | Retrieves a list of all tags for the specified WorkSpaces Applications resource |
| start_app_block_builder | Starts an app block builder |
| start_fleet | Starts the specified fleet |
| start_image_builder | Starts the specified image builder |
| start_software_deployment_to_image_builder | Initiates license included applications deployment to an image builder instance |
| stop_app_block_builder | Stops an app block builder |
| stop_fleet | Stops the specified fleet |
| stop_image_builder | Stops the specified image builder |
| tag_resource | Adds or overwrites one or more tags for the specified WorkSpaces Applications resource |
| untag_resource | Disassociates one or more specified tags from the specified WorkSpaces Applications resource |
| update_app_block_builder | Updates an app block builder |
| update_application | Updates the specified application |
| update_directory_config | Updates the specified Directory Config object in WorkSpaces Applications |
| update_entitlement | Updates the specified entitlement |
| update_fleet | Updates the specified fleet |
| update_image_permissions | Adds or updates permissions for the specified private image |
| update_stack | Updates the specified fields for the specified stack |
| update_theme_for_stack | Updates custom branding that customizes the appearance of the streaming application catalog page |
## Not run:
svc <- appstream()
svc$associate_app_block_builder_app_block(
Foo = 123
)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.