bedrockagentcorecontrol: Amazon Bedrock AgentCore Control

View source: R/paws.R

bedrockagentcorecontrolR Documentation

Amazon Bedrock AgentCore Control

Description

Welcome to the Amazon Bedrock AgentCore Control plane API reference. Control plane actions configure, create, modify, and monitor Amazon Web Services resources.

Usage

bedrockagentcorecontrol(
  config = list(),
  credentials = list(),
  endpoint = NULL,
  region = NULL
)

Arguments

config

Optional configuration of credentials, endpoint, and/or region.

  • credentials:

    • creds:

      • access_key_id: AWS access key ID

      • secret_access_key: AWS secret access key

      • session_token: AWS temporary session token

    • profile: The name of a profile to use. If not given, then the default profile is used.

    • anonymous: Set anonymous credentials.

  • endpoint: The complete URL to use for the constructed client.

  • region: The AWS Region used in instantiating the client.

  • close_connection: Immediately close all HTTP connections.

  • timeout: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.

  • s3_force_path_style: Set this to true to force the request to use path-style addressing, i.e. ⁠http://s3.amazonaws.com/BUCKET/KEY⁠.

  • sts_regional_endpoint: Set sts regional endpoint resolver to regional or legacy https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html

  • use_dual_stack: Set this to true to use the dualstack (IPv4 and IPv6) endpoint for a service, where available, falling back to the regular endpoint when it isn't. Defaults to the AWS_USE_DUALSTACK_ENDPOINT environment variable when unset.

credentials

Optional credentials shorthand for the config parameter

  • creds:

    • access_key_id: AWS access key ID

    • secret_access_key: AWS secret access key

    • session_token: AWS temporary session token

  • profile: The name of a profile to use. If not given, then the default profile is used.

  • anonymous: Set anonymous credentials.

endpoint

Optional shorthand for complete URL to use for the constructed client.

region

Optional shorthand for AWS Region used in instantiating the client.

Value

A client for the service. You can call the service's operations using syntax like svc$operation(...), where svc is the name you've assigned to the client. The available operations are listed in the Operations section.

Service syntax

svc <- bedrockagentcorecontrol(
  config = list(
    credentials = list(
      creds = list(
        access_key_id = "string",
        secret_access_key = "string",
        session_token = "string"
      ),
      profile = "string",
      anonymous = "logical"
    ),
    endpoint = "string",
    region = "string",
    close_connection = "logical",
    timeout = "numeric",
    s3_force_path_style = "logical",
    sts_regional_endpoint = "string",
    use_dual_stack = "logical"
  ),
  credentials = list(
    creds = list(
      access_key_id = "string",
      secret_access_key = "string",
      session_token = "string"
    ),
    profile = "string",
    anonymous = "logical"
  ),
  endpoint = "string",
  region = "string"
)

Operations

add_dataset_examples Adds examples to the dataset's DRAFT
batch_put_gateway_rate_limits Atomically creates or updates multiple rate limits for a gateway
create_agent_runtime Creates an Amazon Bedrock AgentCore Runtime
create_agent_runtime_endpoint Creates an AgentCore Runtime endpoint
create_api_key_credential_provider Creates a new API key credential provider
create_browser Creates a custom browser
create_browser_profile Creates a browser profile in Amazon Bedrock AgentCore
create_capacity_provider Creates a capacity provider
create_code_interpreter Creates a custom code interpreter
create_configuration_bundle Creates a new configuration bundle resource
create_consent_portal Creates a new consent portal
create_dataset Creates a new dataset resource asynchronously
create_dataset_version Publishes the current DRAFT as a new numbered version
create_evaluator Creates a custom evaluator for agent quality assessment
create_gateway Creates a gateway for Amazon Bedrock Agent
create_gateway_rate_limit Creates a rate limit for a gateway
create_gateway_rule Creates a rule for a gateway
create_gateway_target Creates a target for a gateway
create_harness Operation to create a harness
create_harness_endpoint Operation to create a harness endpoint
create_memory Creates a new Amazon Bedrock AgentCore Memory resource
create_oauth_2_credential_provider Creates a new OAuth2 credential provider
create_online_evaluation_config Creates an online evaluation configuration for continuous monitoring of agent performance
create_payment_connector Creates a new payment connector for a payment manager
create_payment_credential_provider Creates a new payment credential provider for storing authentication credentials used by payment connectors to communicate with external payment providers
create_payment_manager Creates a new payment manager in your Amazon Web Services account
create_policy Creates a policy within the AgentCore Policy system
create_policy_engine Creates a new policy engine within the AgentCore Policy system
create_registry Creates a new registry in your Amazon Web Services account
create_registry_record Creates a new registry record within the specified registry
create_workload_identity Creates a new workload identity
delete_agent_runtime Deletes an Amazon Bedrock AgentCore Runtime, or a single version of an AgentCore Runtime when you provide the version qualifier
delete_agent_runtime_endpoint Deletes an AgentCore Runtime endpoint
delete_api_key_credential_provider Deletes an API key credential provider
delete_browser Deletes a custom browser
delete_browser_profile Deletes a browser profile
delete_capacity_provider Deletes a capacity provider
delete_code_interpreter Deletes a custom code interpreter
delete_configuration_bundle Deletes a configuration bundle and all of its versions
delete_consent_portal Deletes a consent portal
delete_dataset Deletes a dataset version or an entire dataset asynchronously
delete_dataset_examples Deletes specific examples by ID from DRAFT
delete_evaluator Deletes a custom evaluator
delete_gateway Deletes a gateway
delete_gateway_rate_limit Deletes a gateway rate limit
delete_gateway_rule Deletes a gateway rule
delete_gateway_target Deletes a gateway target
delete_harness Operation to delete a Harness
delete_harness_endpoint Operation to delete a harness endpoint
delete_memory Deletes an Amazon Bedrock AgentCore Memory resource
delete_oauth_2_credential_provider Deletes an OAuth2 credential provider
delete_online_evaluation_config Deletes an online evaluation configuration and stops any ongoing evaluation processes associated with it
delete_payment_connector Deletes a payment connector
delete_payment_credential_provider Deletes a payment credential provider and its associated stored credentials
delete_payment_manager Deletes a payment manager
delete_policy Deletes an existing policy from the AgentCore Policy system
delete_policy_engine Deletes an existing policy engine from the AgentCore Policy system
delete_registry Deletes a registry
delete_registry_record Deletes a registry record
delete_resource_policy Deletes the resource-based policy for a specified resource
delete_workload_identity Deletes a workload identity
get_agent_runtime Gets an Amazon Bedrock AgentCore Runtime
get_agent_runtime_endpoint Gets information about an Amazon Secure AgentEndpoint
get_api_key_credential_provider Retrieves information about an API key credential provider
get_browser Gets information about a custom browser
get_browser_profile Gets information about a browser profile
get_capacity_provider Retrieves information about a capacity provider, including its status, permissions configuration, and compute configuration
get_code_interpreter Gets information about a custom code interpreter
get_configuration_bundle Gets the latest version of a configuration bundle
get_configuration_bundle_version Gets a specific version of a configuration bundle by its version identifier
get_consent_portal Retrieves information about a consent portal
get_dataset Retrieves dataset metadata
get_evaluator Retrieves detailed information about an evaluator, including its configuration, status, and metadata
get_gateway Retrieves information about a specific Gateway
get_gateway_rate_limit Retrieves information about a gateway rate limit
get_gateway_rule Retrieves detailed information about a specific gateway rule
get_gateway_target Retrieves information about a specific gateway target
get_harness Operation to get a single harness
get_harness_endpoint Operation to get a single harness endpoint
get_memory Retrieve an existing Amazon Bedrock AgentCore Memory resource
get_oauth_2_credential_provider Retrieves information about an OAuth2 credential provider
get_online_evaluation_config Retrieves detailed information about an online evaluation configuration, including its rules, data sources, evaluators, and execution status
get_payment_connector Retrieves information about a specific payment connector
get_payment_credential_provider Retrieves information about a specific payment credential provider
get_payment_manager Retrieves information about a specific payment manager
get_policy Retrieves detailed information about a specific policy within the AgentCore Policy system
get_policy_engine Retrieves detailed information about a specific policy engine within the AgentCore Policy system
get_policy_engine_summary Retrieves a metadata-only summary of a specific policy engine without decrypting customer content
get_policy_generation Retrieves information about a policy generation request within the AgentCore Policy system
get_policy_generation_summary Retrieves a metadata-only summary of a specific policy generation request without decrypting customer content
get_policy_summary Retrieves a metadata-only summary of a specific policy without decrypting customer content
get_registry Retrieves information about a specific registry
get_registry_record Retrieves information about a specific registry record
get_resource_policy Retrieves the resource-based policy for a specified resource
get_token_vault Retrieves information about a token vault
get_workload_identity Retrieves information about a workload identity
list_agent_runtime_endpoints Lists all endpoints for a specific Amazon Secure Agent
list_agent_runtimes Lists all Amazon Secure Agents in your account
list_agent_runtime_versions Lists all versions of a specific Amazon Secure Agent
list_agent_runtime_versions_by_capacity_provider Lists the agent runtime versions that are associated with a capacity provider
list_api_key_credential_providers Lists all API key credential providers in your account
list_browser_profiles Lists all browser profiles in your account
list_browsers Lists all custom browsers in your account
list_capacity_providers Lists the capacity providers in your account and returns summary information for each one
list_code_interpreters Lists all custom code interpreters in your account
list_configuration_bundles Lists all configuration bundles in the account
list_configuration_bundle_versions Lists all versions of a configuration bundle, with optional filtering by branch name or creation source
list_consent_portals Lists all of the consent portals in your account
list_dataset_examples Returns paginated examples from the dataset
list_datasets Lists all datasets in the caller's account, paginated
list_dataset_versions Lists all published versions of a dataset, sorted by version number descending (newest first)
list_evaluators Lists all available evaluators, including both builtin evaluators provided by the service and custom evaluators created by the user
list_gateway_rate_limits Lists all rate limits for a gateway
list_gateway_rules Lists all rules for a gateway
list_gateways Lists all gateways in the account
list_gateway_targets Lists all targets for a specific gateway
list_harness_endpoints Operation to list the endpoints of a harness
list_harnesses Operation to list harnesses
list_harness_versions Operation to list the versions of a Harness
list_memories Lists the available Amazon Bedrock AgentCore Memory resources in the current Amazon Web Services Region
list_oauth_2_credential_providers Lists all OAuth2 credential providers in your account
list_online_evaluation_configs Lists all online evaluation configurations in the account, providing summary information about each configuration's status and settings
list_payment_connectors Lists all payment connectors for a specified payment manager
list_payment_credential_providers Lists all payment credential providers in the account
list_payment_managers Lists all payment managers in the account
list_policies Retrieves a list of policies within the AgentCore Policy engine
list_policy_engines Retrieves a list of policy engines within the AgentCore Policy system
list_policy_engine_summaries Retrieves a paginated list of metadata-only policy engine summaries without decrypting customer content
list_policy_generation_assets Retrieves a list of generated policy assets from a policy generation request within the AgentCore Policy system
list_policy_generations Retrieves a list of policy generation requests within the AgentCore Policy system
list_policy_generation_summaries Retrieves a paginated list of metadata-only policy generation summaries within a policy engine without decrypting customer content
list_policy_summaries Retrieves a paginated list of metadata-only policy summaries within a policy engine without decrypting customer content
list_registries Lists all registries in the account
list_registry_records Lists registry records within a registry
list_tags_for_resource Lists the tags associated with the specified resource
list_workload_identities Lists all workload identities in your account
put_resource_policy Creates or updates a resource-based policy for a resource with the specified resourceArn
rotate_payment_connector_credentials Replaces the service-managed credentials of a payment connector with newly issued credentials
set_token_vault_cmk Sets the customer master key (CMK) for a token vault
start_policy_generation Initiates the AI-powered generation of Dogwood policies from natural language descriptions within the AgentCore Policy system
submit_registry_record_for_approval Submits a registry record for approval
synchronize_gateway_targets Synchronizes the gateway targets by fetching the latest tool definitions from the target endpoints
tag_resource Associates the specified tags to a resource with the specified resourceArn
untag_resource Removes the specified tags from the specified resource
update_agent_runtime Updates an existing Amazon Secure Agent
update_agent_runtime_endpoint Updates an existing Amazon Bedrock AgentCore Runtime endpoint
update_api_key_credential_provider Updates an existing API key credential provider
update_capacity_provider Updates a capacity provider
update_configuration_bundle Updates a configuration bundle by creating a new version with the specified changes
update_consent_portal Updates an existing consent portal
update_dataset Updates a dataset's metadata
update_dataset_examples Updates multiple existing examples in-place on DRAFT
update_evaluator Updates a custom evaluator's configuration, description, or evaluation level
update_gateway Updates an existing gateway
update_gateway_rate_limit Updates the entries of a gateway rate limit
update_gateway_rule Updates a gateway rule's priority, conditions, actions, or description
update_gateway_target Updates an existing gateway target
update_harness Operation to update a harness
update_harness_endpoint Operation to update a harness endpoint
update_memory Update an Amazon Bedrock AgentCore Memory resource memory
update_oauth_2_credential_provider Updates an existing OAuth2 credential provider
update_online_evaluation_config Updates an online evaluation configuration's settings, including rules, data sources, evaluators, and execution status
update_payment_connector Updates an existing payment connector
update_payment_credential_provider Updates an existing payment credential provider with new authentication credentials
update_payment_manager Updates an existing payment manager
update_policy Updates an existing policy within the AgentCore Policy system
update_policy_engine Updates an existing policy engine within the AgentCore Policy system
update_registry Updates an existing registry
update_registry_record Updates an existing registry record
update_registry_record_status Updates the status of a registry record
update_workload_identity Updates an existing workload identity

Examples

## Not run: 
svc <- bedrockagentcorecontrol()
svc$add_dataset_examples(
  Foo = 123
)

## End(Not run)


paws documentation built on Oct. 8, 2026, 5:07 p.m.