connect: Amazon Connect Service

View source: R/paws.R

connectR Documentation

Amazon Connect Service

Description

Connect Customer is a cloud-based contact center solution that you use to set up and manage a customer contact center and provide reliable customer engagement at any scale.

Connect Customer provides metrics and real-time reporting that enable you to optimize contact routing. You can also resolve customer issues more efficiently by getting customers in touch with the appropriate agents.

There are limits to the number of Connect Customer resources that you can create. There are also limits to the number of requests that you can make per second. For more information, see Connect Customer Service Quotas in the Connect Customer Administrator Guide.

You can use an endpoint to connect programmatically to an Amazon Web Services service. For a list of Connect Customer endpoints, see Connect Customer Endpoints.

Usage

connect(config = list(), credentials = list(), endpoint = NULL, region = NULL)

Arguments

config

Optional configuration of credentials, endpoint, and/or region.

  • credentials:

    • creds:

      • access_key_id: AWS access key ID

      • secret_access_key: AWS secret access key

      • session_token: AWS temporary session token

    • profile: The name of a profile to use. If not given, then the default profile is used.

    • anonymous: Set anonymous credentials.

  • endpoint: The complete URL to use for the constructed client.

  • region: The AWS Region used in instantiating the client.

  • close_connection: Immediately close all HTTP connections.

  • timeout: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.

  • s3_force_path_style: Set this to true to force the request to use path-style addressing, i.e. ⁠http://s3.amazonaws.com/BUCKET/KEY⁠.

  • sts_regional_endpoint: Set sts regional endpoint resolver to regional or legacy https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html

credentials

Optional credentials shorthand for the config parameter

  • creds:

    • access_key_id: AWS access key ID

    • secret_access_key: AWS secret access key

    • session_token: AWS temporary session token

  • profile: The name of a profile to use. If not given, then the default profile is used.

  • anonymous: Set anonymous credentials.

endpoint

Optional shorthand for complete URL to use for the constructed client.

region

Optional shorthand for AWS Region used in instantiating the client.

Value

A client for the service. You can call the service's operations using syntax like svc$operation(...), where svc is the name you've assigned to the client. The available operations are listed in the Operations section.

Service syntax

svc <- connect(
  config = list(
    credentials = list(
      creds = list(
        access_key_id = "string",
        secret_access_key = "string",
        session_token = "string"
      ),
      profile = "string",
      anonymous = "logical"
    ),
    endpoint = "string",
    region = "string",
    close_connection = "logical",
    timeout = "numeric",
    s3_force_path_style = "logical",
    sts_regional_endpoint = "string"
  ),
  credentials = list(
    creds = list(
      access_key_id = "string",
      secret_access_key = "string",
      session_token = "string"
    ),
    profile = "string",
    anonymous = "logical"
  ),
  endpoint = "string",
  region = "string"
)

Operations

activate_evaluation_form Activates an evaluation form in the specified Connect Customer instance
associate_analytics_data_set Associates the specified dataset for a Connect Customer instance with the target account
associate_approved_origin This API is in preview release for Connect Customer and is subject to change
associate_bot This API is in preview release for Connect Customer and is subject to change
associate_contact_with_user Associates a queued contact with an agent
associate_default_vocabulary Associates an existing vocabulary as the default
associate_email_address_alias Associates an email address alias with an existing email address in an Connect Customer instance
associate_flow Associates a connect resource to a flow
associate_hours_of_operations Associates a set of hours of operations with another hours of operation
associate_instance_storage_config This API is in preview release for Connect Customer and is subject to change
associate_lambda_function This API is in preview release for Connect Customer and is subject to change
associate_lex_bot This API is in preview release for Connect Customer and is subject to change
associate_phone_number_contact_flow Associates a flow with a phone number claimed to your Connect Customer instance
associate_queue_email_addresses Associates a set of email addresses with a queue to enable agents to select different "From" (system) email addresses when replying to inbound email contacts or initiating outbound email contacts
associate_queue_quick_connects Associates a set of quick connects with a queue
associate_routing_profile_queues Associates a set of queues with a routing profile
associate_security_key This API is in preview release for Connect Customer and is subject to change
associate_security_profiles Associate security profiles with an Entity in an Amazon Connect instance
associate_traffic_distribution_group_user Associates an agent with a traffic distribution group
associate_user_proficiencies Associates a set of proficiencies with a user
associate_workspace Associates a workspace with one or more users or routing profiles, allowing them to access the workspace's configured views and pages
batch_associate_analytics_data_set Associates a list of analytics datasets for a given Connect Customer instance to a target account
batch_create_data_table_value Creates values for attributes in a data table
batch_delete_data_table_value Deletes multiple values from a data table
batch_describe_data_table_value Retrieves multiple values from a data table without evaluating expressions
batch_disassociate_analytics_data_set Removes a list of analytics datasets associated with a given Connect Customer instance
batch_get_attached_file_metadata Allows you to retrieve metadata about multiple attached files on an associated resource
batch_get_flow_association Retrieve the flow associations for the given resources
batch_put_contact Only the Connect Customer outbound campaigns service principal is allowed to assume a role in your account and call this API
batch_update_data_table_value Updates multiple data table values using all properties from BatchCreateDataTableValue
claim_phone_number Claims an available phone number to your Connect Customer instance or traffic distribution group
complete_attached_file_upload Allows you to confirm that the attached file has been uploaded using the pre-signed URL provided in the StartAttachedFileUpload API
create_agent_status Creates an agent status for the specified Connect Customer instance
create_contact Only the VOICE, EMAIL, and TASK channels are supported
create_contact_flow Creates a flow for the specified Connect Customer instance
create_contact_flow_module Creates a flow module for the specified Connect Customer instance
create_contact_flow_module_alias Creates a named alias that points to a specific version of a contact flow module
create_contact_flow_module_version Creates an immutable snapshot of a contact flow module, preserving its content and settings at a specific point in time for version control and rollback capabilities
create_contact_flow_version Publishes a new version of the flow provided
create_data_table Creates a new data table with the specified properties
create_data_table_attribute Adds an attribute to an existing data table
create_email_address Create new email address in the specified Connect Customer instance
create_evaluation_form Creates an evaluation form in the specified Connect Customer instance
create_hours_of_operation Creates hours of operation
create_hours_of_operation_override Creates an hours of operation override in an Connect Customer hours of operation resource
create_instance This API is in preview release for Connect Customer and is subject to change
create_integration_association Creates an Amazon Web Services resource association with an Connect Customer instance
create_notification Creates a new notification to be delivered to specified recipients
create_participant Adds a new participant into an on-going chat contact or webRTC call
create_persistent_contact_association Enables rehydration of chats for the lifespan of a contact
create_predefined_attribute Creates a new predefined attribute for the specified Connect Customer instance
create_prompt Creates a prompt
create_push_notification_registration Creates registration for a device token and a chat contact to receive real-time push notifications
create_queue Creates a new queue for the specified Connect Customer instance
create_quick_connect Creates a quick connect for the specified Connect Customer instance
create_routing_profile Creates a new routing profile
create_rule Creates a rule for the specified Connect Customer instance
create_security_profile Creates a security profile
create_task_template Creates a new task template in the specified Connect Customer instance
create_test_case Creates a test case with its content and metadata for the specified Amazon Connect instance
create_traffic_distribution_group Creates a traffic distribution group given an Connect Customer instance that has been replicated
create_use_case Creates a use case for an integration association
create_user Creates a user account for the specified Connect Customer instance
create_user_hierarchy_group Creates a new user hierarchy group
create_view Creates a new view with the possible status of SAVED or PUBLISHED
create_view_version Publishes a new version of the view identifier
create_vocabulary Creates a custom vocabulary associated with your Connect Customer instance
create_workspace Creates a workspace that defines the user experience by mapping views to pages
create_workspace_page Associates a view with a page in a workspace, defining what users see when they navigate to that page
deactivate_evaluation_form Deactivates an evaluation form in the specified Connect Customer instance
delete_attached_file Deletes an attached file along with the underlying S3 Object
delete_contact_evaluation Deletes a contact evaluation in the specified Connect Customer instance
delete_contact_flow Deletes a flow for the specified Connect Customer instance
delete_contact_flow_module Deletes the specified flow module
delete_contact_flow_module_alias Removes an alias reference, breaking the named connection to the underlying module version without affecting the version itself
delete_contact_flow_module_version Removes a specific version of a contact flow module
delete_contact_flow_version Deletes the particular version specified in flow version identifier
delete_data_table Deletes a data table and all associated attributes, versions, audits, and values
delete_data_table_attribute Deletes an attribute and all its values from a data table
delete_email_address Deletes email address from the specified Connect Customer instance
delete_evaluation_form Deletes an evaluation form in the specified Connect Customer instance
delete_hours_of_operation Deletes an hours of operation
delete_hours_of_operation_override Deletes an hours of operation override in an Connect Customer hours of operation resource
delete_instance This API is in preview release for Connect Customer and is subject to change
delete_integration_association Deletes an Amazon Web Services resource association from an Connect Customer instance
delete_notification Deletes a notification
delete_predefined_attribute Deletes a predefined attribute from the specified Connect Customer instance
delete_prompt Deletes a prompt
delete_push_notification_registration Deletes registration for a device token and a chat contact
delete_queue Deletes a queue
delete_quick_connect Deletes a quick connect
delete_routing_profile Deletes a routing profile
delete_rule Deletes a rule for the specified Connect Customer instance
delete_security_profile Deletes a security profile
delete_task_template Deletes the task template
delete_test_case Deletes the test case that has already been created for the specified Amazon Connect instance
delete_traffic_distribution_group Deletes a traffic distribution group
delete_use_case Deletes a use case from an integration association
delete_user Deletes a user account from the specified Connect Customer instance
delete_user_hierarchy_group Deletes an existing user hierarchy group
delete_view Deletes the view entirely
delete_view_version Deletes the particular version specified in ViewVersion identifier
delete_vocabulary Deletes the vocabulary that has the given identifier
delete_workspace Deletes a workspace and removes all associated view and resource assignments
delete_workspace_media Deletes a media asset (such as a logo) from a workspace
delete_workspace_page Removes the association between a view and a page in a workspace
describe_agent_status Describes an agent status
describe_attached_files_configuration Describes the attached files configuration for the specified Connect Customer instance and attachment scope
describe_authentication_profile This API is in preview release for Connect Customer and is subject to change
describe_contact This API is in preview release for Connect Customer and is subject to change
describe_contact_evaluation Describes a contact evaluation in the specified Connect Customer instance
describe_contact_flow Describes the specified flow
describe_contact_flow_module Describes the specified flow module
describe_contact_flow_module_alias Retrieves detailed information about a specific alias, including which version it currently points to and its metadata
describe_data_table Returns all properties for a data table except for attributes and values
describe_data_table_attribute Returns detailed information for a specific data table attribute including its configuration, validation rules, and metadata
describe_email_address Describe email address form the specified Connect Customer instance
describe_evaluation_form Describes an evaluation form in the specified Connect Customer instance
describe_hours_of_operation Describes the hours of operation
describe_hours_of_operation_override Describes the hours of operation override
describe_instance This API is in preview release for Connect Customer and is subject to change
describe_instance_attribute This API is in preview release for Connect Customer and is subject to change
describe_instance_storage_config This API is in preview release for Connect Customer and is subject to change
describe_notification Retrieves detailed information about a specific notification, including its content, priority, recipients, and metadata
describe_phone_number Gets details and status of a phone number that’s claimed to your Connect Customer instance or traffic distribution group
describe_predefined_attribute Describes a predefined attribute for the specified Connect Customer instance
describe_prompt Describes the prompt
describe_queue Describes the specified queue
describe_quick_connect Describes the quick connect
describe_routing_profile Describes the specified routing profile
describe_rule Describes a rule for the specified Connect Customer instance
describe_security_profile Gets basic information about the security profile
describe_test_case Describes the specified test case and allows you to get the content and metadata of the test case for the specified Amazon Connect instance
describe_traffic_distribution_group Gets details and status of a traffic distribution group
describe_user Describes the specified user
describe_user_hierarchy_group Describes the specified hierarchy group
describe_user_hierarchy_structure Describes the hierarchy structure of the specified Connect Customer instance
describe_view Retrieves the view for the specified Connect Customer instance and view identifier
describe_vocabulary Describes the specified vocabulary
describe_workspace Retrieves details about a workspace, including its configuration and metadata
disassociate_analytics_data_set Removes the dataset ID associated with a given Connect Customer instance
disassociate_approved_origin This API is in preview release for Connect Customer and is subject to change
disassociate_bot This API is in preview release for Connect Customer and is subject to change
disassociate_email_address_alias Removes the alias association between two email addresses in an Connect Customer instance
disassociate_flow Disassociates a connect resource from a flow
disassociate_hours_of_operations Disassociates a set of hours of operations with another hours of operation
disassociate_instance_storage_config This API is in preview release for Connect Customer and is subject to change
disassociate_lambda_function This API is in preview release for Connect Customer and is subject to change
disassociate_lex_bot This API is in preview release for Connect Customer and is subject to change
disassociate_phone_number_contact_flow Removes the flow association from a phone number claimed to your Connect Customer instance
disassociate_queue_email_addresses Removes the association between a set of email addresses and a queue
disassociate_queue_quick_connects Disassociates a set of quick connects from a queue
disassociate_routing_profile_queues Disassociates a set of queues from a routing profile
disassociate_security_key This API is in preview release for Connect Customer and is subject to change
disassociate_security_profiles Disassociates a security profile attached to a Q in Connect AI Agent Entity in an Amazon Connect instance
disassociate_traffic_distribution_group_user Disassociates an agent from a traffic distribution group
disassociate_user_proficiencies Disassociates a set of proficiencies from a user
disassociate_workspace Removes the association between a workspace and one or more users or routing profiles
dismiss_user_contact Dismisses contacts from an agent’s CCP and returns the agent to an available state, which allows the agent to receive a new routed contact
evaluate_data_table_values Evaluates values at the time of the request and returns them
get_attached_file Provides a pre-signed URL for download of an approved attached file
get_contact_attributes Retrieves the contact attributes for the specified contact
get_contact_metrics Retrieves contact metric data for a specified contact
get_current_metric_data Gets the real-time metric data from the specified Connect Customer instance
get_current_user_data Gets the real-time active user data from the specified Connect Customer instance
get_effective_hours_of_operations Get the hours of operations with the effective override applied
get_federation_token Supports SAML sign-in for Connect Customer
get_flow_association Retrieves the flow associated for a given resource
get_metric_data Gets historical metric data from the specified Connect Customer instance
get_metric_data_v2 Gets metric data from the specified Connect Customer instance
get_prompt_file Gets the prompt file
get_task_template Gets details about a specific task template in the specified Connect Customer instance
get_test_case_execution_summary Retrieves an overview of a test execution that includes the status of the execution, start and end time, and observation summary
get_traffic_distribution Retrieves the current traffic distribution for a given traffic distribution group
import_phone_number Imports a claimed phone number from an external service, such as Amazon Web Services End User Messaging, into an Connect Customer instance
import_workspace_media Imports a media asset (such as a logo) for use in a workspace
list_agent_statuses Lists agent statuses
list_analytics_data_associations Lists the association status of requested dataset ID for a given Connect Customer instance
list_analytics_data_lake_data_sets Lists the data lake datasets available to associate with for a given Connect Customer instance
list_approved_origins This API is in preview release for Connect Customer and is subject to change
list_associated_contacts Provides information about contact tree, a list of associated contacts with a unique identifier
list_attached_files_configurations Provides summary information about the attached files configurations for the specified Connect Customer instance
list_authentication_profiles This API is in preview release for Connect Customer and is subject to change
list_bots This API is in preview release for Connect Customer and is subject to change
list_child_hours_of_operations Provides information about the child hours of operations for the specified parent hours of operation
list_contact_evaluations Lists contact evaluations in the specified Connect Customer instance
list_contact_flow_module_aliases Lists all aliases associated with a contact flow module, showing their current version mappings and metadata
list_contact_flow_modules Provides information about the flow modules for the specified Connect Customer instance
list_contact_flow_module_versions Retrieves a paginated list of all versions for a specific contact flow module
list_contact_flows Provides information about the flows for the specified Connect Customer instance
list_contact_flow_versions Returns all the available versions for the specified Connect Customer instance and flow identifier
list_contact_references This API is in preview release for Connect Customer and is subject to change
list_data_table_attributes Returns all attributes for a specified data table
list_data_table_primary_values Lists all primary value combinations for a given data table
list_data_tables Lists all data tables for the specified Amazon Connect instance
list_data_table_values Lists values stored in a data table with optional filtering by record IDs or primary attribute values
list_default_vocabularies Lists the default vocabularies for the specified Connect Customer instance
list_entity_security_profiles Lists all security profiles attached to a Q in Connect AIAgent Entity in an Amazon Connect instance
list_evaluation_forms Lists evaluation forms in the specified Connect Customer instance
list_evaluation_form_versions Lists versions of an evaluation form in the specified Connect Customer instance
list_flow_associations List the flow association based on the filters
list_hours_of_operation_overrides List the hours of operation overrides
list_hours_of_operations Provides information about the hours of operation for the specified Connect Customer instance
list_instance_attributes This API is in preview release for Connect Customer and is subject to change
list_instances This API is in preview release for Connect Customer and is subject to change
list_instance_storage_configs This API is in preview release for Connect Customer and is subject to change
list_integration_associations Provides summary information about the Amazon Web Services resource associations for the specified Connect Customer instance
list_lambda_functions This API is in preview release for Connect Customer and is subject to change
list_lex_bots This API is in preview release for Connect Customer and is subject to change
list_notifications Retrieves a paginated list of all notifications in the Amazon Connect instance
list_phone_numbers Provides information about the phone numbers for the specified Connect Customer instance
list_phone_numbers_v2 Lists phone numbers claimed to your Connect Customer instance or traffic distribution group
list_predefined_attributes Lists predefined attributes for the specified Connect Customer instance
list_prompts Provides information about the prompts for the specified Connect Customer instance
list_queue_email_addresses Lists all email addresses that are currently associated with a specific queue, providing details about which "From" email addresses agents can select when handling email contacts
list_queue_quick_connects Lists the quick connects associated with a queue
list_queues Provides information about the queues for the specified Connect Customer instance
list_quick_connects Provides information about the quick connects for the specified Connect Customer instance
list_realtime_contact_analysis_segments_v2 Provides a list of analysis segments for a real-time chat analysis session
list_routing_profile_manual_assignment_queues Lists the manual assignment queues associated with a routing profile
list_routing_profile_queues Lists the queues associated with a routing profile
list_routing_profiles Provides summary information about the routing profiles for the specified Connect Customer instance
list_rules List all rules for the specified Connect Customer instance
list_security_keys This API is in preview release for Connect Customer and is subject to change
list_security_profile_applications Returns a list of third-party applications or MCP Servers in a specific security profile
list_security_profile_flow_modules A list of Flow Modules an AI Agent can invoke as a tool
list_security_profile_permissions Lists the permissions granted to a security profile
list_security_profiles Provides summary information about the security profiles for the specified Connect Customer instance
list_tags_for_resource Lists the tags for the specified resource
list_task_templates Lists task templates for the specified Connect Customer instance
list_test_case_execution_records Lists detailed steps of test case execution that includes all observations along with actions taken and data associated in the specified Amazon Connect instance
list_test_case_executions Lists all test case executions and allows filtering by test case id, test case name, start time, end time or status of the execution for the specified Amazon Connect instance
list_test_cases Lists the test cases present in the specific Amazon Connect instance
list_traffic_distribution_groups Lists traffic distribution groups
list_traffic_distribution_group_users Lists traffic distribution group users
list_use_cases Lists the use cases for the integration association
list_user_hierarchy_groups Provides summary information about the hierarchy groups for the specified Connect Customer instance
list_user_notifications Retrieves a paginated list of notifications for a specific user, including the notification status for that user
list_user_proficiencies Lists proficiencies associated with a user
list_users Provides summary information about the users for the specified Connect Customer instance
list_views Returns views in the given instance
list_view_versions Returns all the available versions for the specified Connect Customer instance and view identifier
list_workspace_media Lists media assets (such as logos) associated with a workspace
list_workspace_pages Lists the page configurations in a workspace, including the views assigned to each page
list_workspaces Lists the workspaces in an Amazon Connect instance
monitor_contact Initiates silent monitoring of a contact
pause_contact Allows pausing an ongoing task contact
put_user_status Changes the current status of a user or agent in Connect Customer
release_phone_number Releases a phone number previously claimed to an Connect Customer instance or traffic distribution group
replicate_instance Replicates an Connect Customer instance in the specified Amazon Web Services Region and copies configuration information for Connect Customer resources across Amazon Web Services Regions
resume_contact Allows resuming a task contact in a paused state
resume_contact_recording When a contact is being recorded, and the recording has been suspended using SuspendContactRecording, this API resumes recording whatever recording is selected in the flow configuration: call, screen, or both
search_agent_statuses Searches AgentStatuses in an Connect Customer instance, with optional filtering
search_available_phone_numbers Searches for available phone numbers that you can claim to your Connect Customer instance or traffic distribution group
search_contact_evaluations Searches contact evaluations in an Connect Customer instance, with optional filtering
search_contact_flow_modules Searches the flow modules in an Connect Customer instance, with optional filtering
search_contact_flows Searches the flows in an Connect Customer instance, with optional filtering
search_contacts Searches contacts in an Connect Customer instance
search_data_tables Searches for data tables based on the table's ID, name, and description
search_email_addresses Searches email address in an instance, with optional filtering
search_evaluation_forms Searches evaluation forms in an Connect Customer instance, with optional filtering
search_hours_of_operation_overrides Searches the hours of operation overrides
search_hours_of_operations Searches the hours of operation in an Connect Customer instance, with optional filtering
search_notifications Searches for notifications based on specified criteria and filters
search_predefined_attributes Searches predefined attributes that meet certain criteria
search_prompts Searches prompts in an Connect Customer instance, with optional filtering
search_queues Searches queues in an Connect Customer instance, with optional filtering
search_quick_connects Searches quick connects in an Connect Customer instance, with optional filtering
search_resource_tags Searches tags used in an Connect Customer instance using optional search criteria
search_routing_profiles Searches routing profiles in an Connect Customer instance, with optional filtering
search_security_profiles Searches security profiles in an Connect Customer instance, with optional filtering
search_test_cases Searches for test cases in the specified Amazon Connect instance, with optional filtering
search_user_hierarchy_groups Searches UserHierarchyGroups in an Connect Customer instance, with optional filtering
search_users Searches users in an Connect Customer instance, with optional filtering
search_views Searches views based on name, description, or tags
search_vocabularies Searches for vocabularies within a specific Connect Customer instance using State, NameStartsWith, and LanguageCode
search_workspace_associations Searches for workspace associations with users or routing profiles based on various criteria
search_workspaces Searches workspaces based on name, description, visibility, or tags
send_chat_integration_event Processes chat integration events from Amazon Web Services or external integrations to Connect Customer
send_outbound_email Send outbound email for outbound campaigns
start_attached_file_upload Provides a pre-signed Amazon S3 URL in response for uploading your content
start_chat_contact Initiates a flow to start a new chat for the customer
start_contact_evaluation Starts an empty evaluation in the specified Connect Customer instance, using the given evaluation form for the particular contact
start_contact_media_processing Enables in-flight message processing for an ongoing chat session
start_contact_recording Starts recording the contact:
start_contact_streaming Initiates real-time message streaming for a new chat contact
start_email_contact Creates an inbound email contact and initiates a flow to start the email contact for the customer
start_outbound_chat_contact Initiates a new outbound SMS or WhatsApp contact to a customer
start_outbound_email_contact Initiates a flow to send an agent reply or outbound email contact (created from the CreateContact API) to a customer
start_outbound_voice_contact Places an outbound call to a contact, and then initiates the flow
start_screen_sharing Starts screen sharing for a contact
start_task_contact Initiates a flow to start a new task contact
start_test_case_execution Starts executing a published test case
start_web_rtc_contact Places an inbound in-app, web, or video call to a contact, and then initiates the flow
stop_contact Ends the specified contact
stop_contact_media_processing Stops in-flight message processing for an ongoing chat session
stop_contact_recording Stops recording a call when a contact is being recorded
stop_contact_streaming Ends message streaming on a specified contact
stop_test_case_execution Stops a running test execution
submit_contact_evaluation Submits a contact evaluation in the specified Connect Customer instance
suspend_contact_recording When a contact is being recorded, this API suspends recording whatever is selected in the flow configuration: call (IVR or agent), screen, or both
tag_contact Adds the specified tags to the contact resource
tag_resource Adds the specified tags to the specified resource
transfer_contact Transfers TASK or EMAIL contacts from one agent or queue to another agent or queue at any point after a contact is created
untag_contact Removes the specified tags from the contact resource
untag_resource Removes the specified tags from the specified resource
update_agent_status Updates agent status
update_attached_files_configuration Updates the attached files configuration for the specified Connect Customer instance and attachment scope
update_authentication_profile This API is in preview release for Connect Customer and is subject to change
update_contact This API is in preview release for Connect Customer and is subject to change
update_contact_attributes Creates or updates user-defined contact attributes associated with the specified contact
update_contact_evaluation Updates details about a contact evaluation in the specified Connect Customer instance
update_contact_flow_content Updates the specified flow
update_contact_flow_metadata Updates metadata about specified flow
update_contact_flow_module_alias Updates a specific Aliases metadata, including the version it’s tied to, it’s name, and description
update_contact_flow_module_content Updates specified flow module for the specified Connect Customer instance
update_contact_flow_module_metadata Updates metadata about specified flow module
update_contact_flow_name The name of the flow
update_contact_routing_data Updates routing priority and age on the contact (QueuePriority and QueueTimeAdjustmentInSeconds)
update_contact_schedule Updates the scheduled time of a task contact that is already scheduled
update_data_table_attribute Updates all properties for an attribute using all properties from CreateDataTableAttribute
update_data_table_metadata Updates the metadata properties of a data table
update_data_table_primary_values Updates the primary values for a record
update_email_address_metadata Updates an email address metadata
update_evaluation_form Updates details about a specific evaluation form version in the specified Connect Customer instance
update_hours_of_operation Updates the hours of operation
update_hours_of_operation_override Update the hours of operation override
update_instance_attribute This API is in preview release for Connect Customer and is subject to change
update_instance_storage_config This API is in preview release for Connect Customer and is subject to change
update_notification_content Updates the localized content of an existing notification
update_participant_authentication Instructs Connect Customer to resume the authentication process
update_participant_role_config Updates timeouts for when human chat participants are to be considered idle, and when agents are automatically disconnected from a chat due to idleness
update_phone_number Updates your claimed phone number from its current Connect Customer instance or traffic distribution group to another Connect Customer instance or traffic distribution group in the same Amazon Web Services Region
update_phone_number_metadata Updates a phone number’s metadata
update_predefined_attribute Updates a predefined attribute for the specified Connect Customer instance
update_prompt Updates a prompt
update_queue_hours_of_operation Updates the hours of operation for the specified queue
update_queue_max_contacts Updates the maximum number of contacts allowed in a queue before it is considered full
update_queue_name Updates the name and description of a queue
update_queue_outbound_caller_config Updates the outbound caller ID name, number, and outbound whisper flow for a specified queue
update_queue_outbound_email_config Updates the outbound email address Id for a specified queue
update_queue_status Updates the status of the queue
update_quick_connect_config Updates the configuration settings for the specified quick connect
update_quick_connect_name Updates the name and description of a quick connect
update_routing_profile_agent_availability_timer Whether agents with this routing profile will have their routing order calculated based on time since their last inbound contact or longest idle time
update_routing_profile_concurrency Updates the channels that agents can handle in the Contact Control Panel (CCP) for a routing profile
update_routing_profile_default_outbound_queue Updates the default outbound queue of a routing profile
update_routing_profile_name Updates the name and description of a routing profile
update_routing_profile_queues Updates the properties associated with a set of queues for a routing profile
update_rule Updates a rule for the specified Connect Customer instance
update_security_profile Updates a security profile
update_task_template Updates details about a specific task template in the specified Connect Customer instance
update_test_case Updates any of the metadata for a test case, such as the name, description, and status or content of an existing test case
update_traffic_distribution Updates the traffic distribution for a given traffic distribution group
update_user_config Updates the configuration settings for the specified user, including per-channel auto-accept and after contact work (ACW) timeout settings
update_user_hierarchy Assigns the specified hierarchy group to the specified user
update_user_hierarchy_group_name Updates the name of the user hierarchy group
update_user_hierarchy_structure Updates the user hierarchy structure: add, remove, and rename user hierarchy levels
update_user_identity_info Updates the identity information for the specified user
update_user_notification_status Updates the status of a notification for a specific user, such as marking it as read or hidden
update_user_phone_config Updates the phone configuration settings for the specified user
update_user_proficiencies Updates the properties associated with the proficiencies of a user
update_user_routing_profile Assigns the specified routing profile to the specified user
update_user_security_profiles Assigns the specified security profiles to the specified user
update_view_content Updates the view content of the given view identifier in the specified Connect Customer instance
update_view_metadata Updates the view metadata
update_workspace_metadata Updates the metadata of a workspace, such as its name and description
update_workspace_page Updates the configuration of a page in a workspace, including the associated view and input data
update_workspace_theme Updates the theme configuration for a workspace, including colors and styling
update_workspace_visibility Updates the visibility setting of a workspace, controlling whether it is available to all users, assigned users only, or none

Examples

## Not run: 
svc <- connect()
svc$activate_evaluation_form(
  Foo = 123
)

## End(Not run)


paws documentation built on June 2, 2026, 1:06 a.m.

Related to connect in paws...