paymentcryptographycontrolplane: Payment Cryptography Control Plane

View source: R/paws.R

paymentcryptographycontrolplaneR Documentation

Payment Cryptography Control Plane

Description

Amazon Web Services Payment Cryptography Control Plane APIs manage encryption keys for use during payment-related cryptographic operations. You can create, import, export, share, manage, and delete keys. You can also manage Identity and Access Management (IAM) policies for keys. For more information, see Identity and access management in the Amazon Web Services Payment Cryptography User Guide.

To use encryption keys for payment-related transaction processing and associated cryptographic operations, you use the Amazon Web Services Payment Cryptography Data Plane. You can perform actions like encrypt, decrypt, generate, and verify payment-related data.

All Amazon Web Services Payment Cryptography API calls must be signed and transmitted using Transport Layer Security (TLS). We recommend you always use the latest supported TLS version for logging API requests.

Amazon Web Services Payment Cryptography supports CloudTrail for control plane operations, a service that logs Amazon Web Services API calls and related events for your Amazon Web Services account and delivers them to an Amazon S3 bucket you specify. By using the information collected by CloudTrail, you can determine what requests were made to Amazon Web Services Payment Cryptography, who made the request, when it was made, and so on. If you don't configure a trail, you can still view the most recent events in the CloudTrail console. For more information, see the CloudTrail User Guide.

Usage

paymentcryptographycontrolplane(
  config = list(),
  credentials = list(),
  endpoint = NULL,
  region = NULL
)

Arguments

config

Optional configuration of credentials, endpoint, and/or region.

  • credentials:

    • creds:

      • access_key_id: AWS access key ID

      • secret_access_key: AWS secret access key

      • session_token: AWS temporary session token

    • profile: The name of a profile to use. If not given, then the default profile is used.

    • anonymous: Set anonymous credentials.

  • endpoint: The complete URL to use for the constructed client.

  • region: The AWS Region used in instantiating the client.

  • close_connection: Immediately close all HTTP connections.

  • timeout: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.

  • s3_force_path_style: Set this to true to force the request to use path-style addressing, i.e. ⁠http://s3.amazonaws.com/BUCKET/KEY⁠.

  • sts_regional_endpoint: Set sts regional endpoint resolver to regional or legacy https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html

credentials

Optional credentials shorthand for the config parameter

  • creds:

    • access_key_id: AWS access key ID

    • secret_access_key: AWS secret access key

    • session_token: AWS temporary session token

  • profile: The name of a profile to use. If not given, then the default profile is used.

  • anonymous: Set anonymous credentials.

endpoint

Optional shorthand for complete URL to use for the constructed client.

region

Optional shorthand for AWS Region used in instantiating the client.

Value

A client for the service. You can call the service's operations using syntax like svc$operation(...), where svc is the name you've assigned to the client. The available operations are listed in the Operations section.

Service syntax

svc <- paymentcryptographycontrolplane(
  config = list(
    credentials = list(
      creds = list(
        access_key_id = "string",
        secret_access_key = "string",
        session_token = "string"
      ),
      profile = "string",
      anonymous = "logical"
    ),
    endpoint = "string",
    region = "string",
    close_connection = "logical",
    timeout = "numeric",
    s3_force_path_style = "logical",
    sts_regional_endpoint = "string"
  ),
  credentials = list(
    creds = list(
      access_key_id = "string",
      secret_access_key = "string",
      session_token = "string"
    ),
    profile = "string",
    anonymous = "logical"
  ),
  endpoint = "string",
  region = "string"
)

Operations

add_key_replication_regions Adds replication Amazon Web Services Regions to an existing Amazon Web Services Payment Cryptography key, enabling the key to be used for cryptographic operations in additional Amazon Web Services Regions
associate_mpa_team Associates a Multi-Party Approval (MPA) team with a protected operation
create_alias Creates an alias, or a friendly name, for an Amazon Web Services Payment Cryptography key
create_key Creates an Amazon Web Services Payment Cryptography key, a logical representation of a cryptographic key, that is unique in your account and Amazon Web Services Region
delete_alias Deletes the alias, but doesn't affect the underlying key
delete_key Deletes the key material and metadata associated with Amazon Web Services Payment Cryptography key
delete_resource_policy Removes the resource-based policy attached to an Amazon Web Services Payment Cryptography key
disable_default_key_replication_regions Disables Multi-Region key replication settings for the specified Amazon Web Services Regions in your Amazon Web Services account, preventing new keys from being automatically replicated to those regions
disassociate_mpa_team Removes the association between a Multi-Party Approval (MPA) team and a protected operation
enable_default_key_replication_regions Enables Multi-Region key replication settings for your Amazon Web Services account, causing new keys to be automatically replicated to the specified Amazon Web Services Regions when created
export_key Exports a key from Amazon Web Services Payment Cryptography
get_alias Gets the Amazon Web Services Payment Cryptography key associated with the alias
get_certificate_signing_request Creates a certificate signing request (CSR) from a key pair
get_default_key_replication_regions Retrieves the list of Amazon Web Services Regions where Multi-Region key replication is currently enabled for your Amazon Web Services account
get_key Gets the key metadata for an Amazon Web Services Payment Cryptography key, including the immutable and mutable attributes specified when the key was created
get_mpa_team_association Returns the Multi-Party Approval (MPA) team association for a protected operation
get_parameters_for_export Gets the export token and the signing key certificate to initiate a TR-34 key export from Amazon Web Services Payment Cryptography
get_parameters_for_import Gets the import token and the wrapping key certificate in PEM format (base64 encoded) to initiate a TR-34 WrappedKeyBlock or a RSA WrappedKeyCryptogram import into Amazon Web Services Payment Cryptography
get_public_key_certificate Gets the public key certificate of the asymmetric key pair that exists within Amazon Web Services Payment Cryptography
get_resource_policy Returns the resource-based policy attached to an Amazon Web Services Payment Cryptography key
import_key Imports symmetric keys and public key certificates in PEM format (base64 encoded) into Amazon Web Services Payment Cryptography
list_aliases Lists the aliases for all keys in the caller's Amazon Web Services account and Amazon Web Services Region
list_keys Lists the keys in the caller's Amazon Web Services account and Amazon Web Services Region
list_tags_for_resource Lists the tags for an Amazon Web Services resource
put_resource_policy Attaches or replaces a resource-based policy on an Amazon Web Services Payment Cryptography key
remove_key_replication_regions Removes Replication Regions from an existing Amazon Web Services Payment Cryptography key, disabling the key's availability for cryptographic operations in the specified Amazon Web Services Regions
restore_key Cancels a scheduled key deletion during the waiting period
start_key_usage Enables an Amazon Web Services Payment Cryptography key, which makes it active for cryptographic operations within Amazon Web Services Payment Cryptography
stop_key_usage Disables an Amazon Web Services Payment Cryptography key, which makes it inactive within Amazon Web Services Payment Cryptography
tag_resource Adds or edits tags on an Amazon Web Services Payment Cryptography key
untag_resource Deletes a tag from an Amazon Web Services Payment Cryptography key
update_alias Associates an existing Amazon Web Services Payment Cryptography alias with a different key

Examples

## Not run: 
svc <- paymentcryptographycontrolplane()
svc$add_key_replication_regions(
  Foo = 123
)

## End(Not run)


paws documentation built on June 2, 2026, 1:06 a.m.