| arczonalshift | R Documentation |
Welcome to the API Reference Guide for zonal shift and zonal autoshift in Amazon Application Recovery Controller (ARC).
You can start a zonal shift to move traffic for a load balancer resource away from an Availability Zone to help your application recover quickly from an impairment in an Availability Zone. For example, you can recover your application from a developer's bad code deployment or from an Amazon Web Services infrastructure failure in a single Availability Zone.
You can also configure zonal autoshift for supported load balancer resources. Zonal autoshift is a capability in ARC where you authorize Amazon Web Services to shift away application resource traffic from an Availability Zone during events, on your behalf, to help reduce your time to recovery. Amazon Web Services starts an autoshift when internal telemetry indicates that there is an Availability Zone impairment that could potentially impact customers.
For more information about using zonal shift and zonal autoshift, see the Amazon Application Recovery Controller Developer Guide.
arczonalshift(
config = list(),
credentials = list(),
endpoint = NULL,
region = NULL
)
config |
Optional configuration of credentials, endpoint, and/or region.
|
credentials |
Optional credentials shorthand for the config parameter
|
endpoint |
Optional shorthand for complete URL to use for the constructed client. |
region |
Optional shorthand for AWS Region used in instantiating the client. |
A client for the service. You can call the service's operations using
syntax like svc$operation(...), where svc is the name you've assigned
to the client. The available operations are listed in the
Operations section.
svc <- arczonalshift(
config = list(
credentials = list(
creds = list(
access_key_id = "string",
secret_access_key = "string",
session_token = "string"
),
profile = "string",
anonymous = "logical"
),
endpoint = "string",
region = "string",
close_connection = "logical",
timeout = "numeric",
s3_force_path_style = "logical",
sts_regional_endpoint = "string"
),
credentials = list(
creds = list(
access_key_id = "string",
secret_access_key = "string",
session_token = "string"
),
profile = "string",
anonymous = "logical"
),
endpoint = "string",
region = "string"
)
| cancel_practice_run | Cancel an in-progress practice run zonal shift in Amazon Application Recovery Controller |
| cancel_zonal_shift | Cancel a zonal shift in Amazon Application Recovery Controller |
| create_practice_run_configuration | A practice run configuration for zonal autoshift is required when you enable zonal autoshift |
| delete_practice_run_configuration | Deletes the practice run configuration for a resource |
| get_autoshift_observer_notification_status | Returns the status of the autoshift observer notification |
| get_managed_resource | Get information about a resource that's been registered for zonal shifts with Amazon Application Recovery Controller in this Amazon Web Services Region |
| list_autoshifts | Returns the autoshifts for an Amazon Web Services Region |
| list_managed_resources | Lists all the resources in your Amazon Web Services account in this Amazon Web Services Region that are managed for zonal shifts in Amazon Application Recovery Controller, and information about them |
| list_zonal_shifts | Lists all active and completed zonal shifts in Amazon Application Recovery Controller in your Amazon Web Services account in this Amazon Web Services Region |
| start_practice_run | Start an on-demand practice run zonal shift in Amazon Application Recovery Controller |
| start_zonal_shift | You start a zonal shift to temporarily move load balancer traffic away from an Availability Zone in an Amazon Web Services Region, to help your application recover immediately, for example, from a developer's bad code deployment or from an Amazon Web Services infrastructure failure in a single Availability Zone |
| update_autoshift_observer_notification_status | Update the status of autoshift observer notification |
| update_practice_run_configuration | Update a practice run configuration to change one or more of the following: add, change, or remove the blocking alarm; change the outcome alarm; or add, change, or remove blocking dates or time windows |
| update_zonal_autoshift_configuration | The zonal autoshift configuration for a resource includes the practice run configuration and the status for running autoshifts, zonal autoshift status |
| update_zonal_shift | Update an active zonal shift in Amazon Application Recovery Controller in your Amazon Web Services account |
## Not run:
svc <- arczonalshift()
svc$cancel_practice_run(
Foo = 123
)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.