| braket | R Documentation |
The Amazon Braket API Reference provides information about the operations and structures supported by Amazon Braket.
To learn about the permissions required to call an Amazon Braket API action, see Actions, resources, and condition keys for Amazon Braket. Amazon Braket Python SDK and the AWS Command Line Interface can be used to make discovery and creation of API calls easier. For more information about Amazon Braket features, see What is Amazon Braket? and important terms and concepts in the Amazon Braket Developer Guide.
In this guide:
CommonParameters
CommonErrors
Available languages for AWS SDK:
Code examples from the Amazon Braket Tutorials GitHub repository:
braket(config = list(), credentials = list(), endpoint = NULL, region = NULL)
config |
Optional configuration of credentials, endpoint, and/or region.
|
credentials |
Optional credentials shorthand for the config parameter
|
endpoint |
Optional shorthand for complete URL to use for the constructed client. |
region |
Optional shorthand for AWS Region used in instantiating the client. |
A client for the service. You can call the service's operations using
syntax like svc$operation(...), where svc is the name you've assigned
to the client. The available operations are listed in the
Operations section.
svc <- braket(
config = list(
credentials = list(
creds = list(
access_key_id = "string",
secret_access_key = "string",
session_token = "string"
),
profile = "string",
anonymous = "logical"
),
endpoint = "string",
region = "string",
close_connection = "logical",
timeout = "numeric",
s3_force_path_style = "logical",
sts_regional_endpoint = "string"
),
credentials = list(
creds = list(
access_key_id = "string",
secret_access_key = "string",
session_token = "string"
),
profile = "string",
anonymous = "logical"
),
endpoint = "string",
region = "string"
)
| cancel_job | Cancels an Amazon Braket hybrid job |
| cancel_quantum_task | Cancels the specified task |
| create_job | Creates an Amazon Braket hybrid job |
| create_quantum_task | Creates a quantum task |
| create_spending_limit | Creates a spending limit for a specified quantum device |
| delete_spending_limit | Deletes an existing spending limit |
| get_device | Retrieves the devices available in Amazon Braket |
| get_job | Retrieves the specified Amazon Braket hybrid job |
| get_quantum_task | Retrieves the specified quantum task |
| list_tags_for_resource | Shows the tags associated with this resource |
| search_devices | Searches for devices using the specified filters |
| search_jobs | Searches for Amazon Braket hybrid jobs that match the specified filter values |
| search_quantum_tasks | Searches for tasks that match the specified filter values |
| search_spending_limits | Searches and lists spending limits based on specified filters |
| tag_resource | Add a tag to the specified resource |
| untag_resource | Remove tags from a resource |
| update_spending_limit | Updates an existing spending limit |
## Not run:
svc <- braket()
svc$cancel_job(
Foo = 123
)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.