| wellarchitected | R Documentation |
Amazon Web Services Well-Architected
Amazon Web Services Well-Architected helps you evaluate your architectures against Amazon Web Services best practices across operational excellence, security, reliability, performance efficiency, cost optimization, and sustainability. The service includes the Amazon Web Services Well-Architected Agent for AI-powered recommendations tailored to your specific environment, and the Well-Architected Tool for conducting reviews and tracking improvements.
This is the Amazon Web Services Well-Architected API Reference. Through this API, you can programmatically access personalized recommendations and automation scripts from the Amazon Web Services Well-Architected Agent, and create and manage workloads, conduct lens reviews, track milestones, manage custom lenses, share workloads across accounts, and manage profiles with the Well-Architected Tool.
For more information about the service, see the Amazon Web Services Well-Architected User Guide.
wellarchitected(
config = list(),
credentials = list(),
endpoint = NULL,
region = NULL
)
config |
Optional configuration of credentials, endpoint, and/or region.
|
credentials |
Optional credentials shorthand for the config parameter
|
endpoint |
Optional shorthand for complete URL to use for the constructed client. |
region |
Optional shorthand for AWS Region used in instantiating the client. |
A client for the service. You can call the service's operations using
syntax like svc$operation(...), where svc is the name you've assigned
to the client. The available operations are listed in the
Operations section.
svc <- wellarchitected(
config = list(
credentials = list(
creds = list(
access_key_id = "string",
secret_access_key = "string",
session_token = "string"
),
profile = "string",
anonymous = "logical"
),
endpoint = "string",
region = "string",
close_connection = "logical",
timeout = "numeric",
s3_force_path_style = "logical",
sts_regional_endpoint = "string",
use_dual_stack = "logical"
),
credentials = list(
creds = list(
access_key_id = "string",
secret_access_key = "string",
session_token = "string"
),
profile = "string",
anonymous = "logical"
),
endpoint = "string",
region = "string"
)
| associate_lenses | Associate a lens to a workload |
| associate_profiles | Associate a profile with a workload |
| create_agent_context | Creates a context associated with an optimization profile |
| create_agent_goal | Creates an optimization goal associated with a profile |
| create_agent_profile | Creates an optimization profile that defines the scope and configuration for generating recommendations |
| create_lens_share | Create a lens share |
| create_lens_version | Create a new lens version |
| create_milestone | Create a milestone for an existing workload |
| create_profile | Create a profile |
| create_profile_share | Create a profile share |
| create_review_template | Create a review template |
| create_template_share | Create a review template share |
| create_workload | Create a new workload |
| create_workload_share | Create a workload share |
| delete_agent_context | Deletes a context associated with a profile |
| delete_agent_goal | Deletes an optimization goal from a profile |
| delete_agent_profile | Deletes an optimization profile and its associated configuration |
| delete_lens | Delete an existing lens |
| delete_lens_share | Delete a lens share |
| delete_profile | Delete a profile |
| delete_profile_share | Delete a profile share |
| delete_review_template | Delete a review template |
| delete_template_share | Delete a review template share |
| delete_workload | Delete an existing workload |
| delete_workload_share | Delete a workload share |
| disassociate_lenses | Disassociate a lens from a workload |
| disassociate_profiles | Disassociate a profile from a workload |
| export_lens | Export an existing lens |
| get_agent_context | Retrieves detailed information about a specific context associated with a profile |
| get_agent_goal | Retrieves detailed information about a specific optimization goal |
| get_agent_profile | Retrieves detailed information about an optimization profile, including its configuration and metadata |
| get_agent_recommendation | Retrieves detailed information about a specific optimization recommendation, including its impact analysis, content, and implementation guidance |
| get_agent_recommendation_generation | Retrieves information about a recommendation generation process, including its status, progress, and results |
| get_answer | Get the answer to a specific question in a workload review |
| get_consolidated_report | Get a consolidated report of your workloads |
| get_global_settings | Global settings for all workloads |
| get_lens | Get an existing lens |
| get_lens_review | Get lens review |
| get_lens_review_report | Get lens review report |
| get_lens_version_difference | Get lens version differences |
| get_milestone | Get a milestone for an existing workload |
| get_profile | Get profile information |
| get_profile_template | Get profile template |
| get_review_template | Get review template |
| get_review_template_answer | Get review template answer |
| get_review_template_lens_review | Get a lens review associated with a review template |
| get_workload | Get an existing workload |
| import_lens | Import a new custom lens or update an existing custom lens |
| list_agent_contexts | Lists contexts associated with a profile |
| list_agent_goals | Lists optimization goals associated with a specified profile |
| list_agent_profiles | Lists optimization profiles in your account |
| list_agent_recommendation_generations | Lists recommendation generation processes for a specified profile |
| list_agent_recommendation_items | Lists recommendation items for a specific recommendation |
| list_agent_recommendations | Lists active optimization recommendations for a specified profile with optional filtering by state |
| list_answers | List of answers for a particular workload and lens |
| list_check_details | List of Trusted Advisor check details by account related to the workload |
| list_check_summaries | List of Trusted Advisor checks summarized for all accounts related to the workload |
| list_lenses | List the available lenses |
| list_lens_review_improvements | List the improvements of a particular lens review |
| list_lens_reviews | List lens reviews for a particular workload |
| list_lens_shares | List the lens shares associated with the lens |
| list_milestones | List all milestones for an existing workload |
| list_notifications | List lens notifications |
| list_profile_notifications | List profile notifications |
| list_profiles | List profiles |
| list_profile_shares | List profile shares |
| list_review_template_answers | List the answers of a review template |
| list_review_templates | List review templates |
| list_share_invitations | List the share invitations |
| list_tags_for_resource | List the tags for a resource |
| list_template_shares | List review template shares |
| list_workloads | Paginated list of workloads |
| list_workload_shares | List the workload shares associated with the workload |
| put_agent_recommendation_feedback | Submits user feedback on a recommendation to help improve future optimization suggestions and track implementation outcomes |
| start_agent_recommendation_generation | Initiates a new recommendation generation process for the specified optimization profile |
| tag_resource | Adds one or more tags to the specified resource |
| untag_resource | Deletes specified tags from a resource |
| update_agent_context | Updates an existing context associated with a profile |
| update_agent_goal | Updates the pillars and title of an existing goal associated with a profile |
| update_agent_profile | Updates an existing optimization profile's configuration, including its pillars, execution role, and aggregation settings |
| update_agent_recommendation_status | Updates the status of a recommendation to track its progress through the implementation lifecycle |
| update_answer | Update the answer to a specific question in a workload review |
| update_global_settings | Update whether the Amazon Web Services account is opted into organization sharing and discovery integration features |
| update_integration | Update integration features |
| update_lens_review | Update lens review for a particular workload |
| update_profile | Update a profile |
| update_review_template | Update a review template |
| update_review_template_answer | Update a review template answer |
| update_review_template_lens_review | Update a lens review associated with a review template |
| update_share_invitation | Update a workload or custom lens share invitation |
| update_workload | Update an existing workload |
| update_workload_share | Update a workload share |
| upgrade_lens_review | Upgrade lens review for a particular workload |
| upgrade_profile_version | Upgrade a profile |
| upgrade_review_template_lens_review | Upgrade the lens review of a review template |
## Not run:
svc <- wellarchitected()
svc$associate_lenses(
Foo = 123
)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.